@@ -198,7 +198,7 @@ add_image_overlay = function(image, image_overlay = NULL, rescale_original = FAL
     if(!preview) {
       return(temp)
     }
-    plot_image(temp, keep_user_par = FALSE)
+    plot_image(temp)
     return(invisible(temp))
   } else {
     save_png(temp, filename)
