@@ -6,17 +6,19 @@
 #'@param falloff Default `1`. Falloff of the exponential.
 #'@param dim Default `c(11, 11)`. The dimensions of the matrix.
 #'@param width Default `3` (`-10` to `10`). The range in which to compute the distribution.
+#'@param rescale_unity Default `FALSE`. If `TRUE`, this will rescale the max value to one. Useful
+#'if wanting to plot the distribution with `plot_image()`.
 #'@import stats
 #'@export
 #'@examples
-#'#if(interactive()){
+#'if(rayimage:::run_documentation()){
 #'image(generate_2d_exponential(1,31,3), asp=1)
-#'#end}
-generate_2d_exponential = function(falloff = 1, dim = c(11,11), width = 3) {
+#'}
+generate_2d_exponential = function(falloff = 1, dim = c(11,11), width = 3,
+                                   rescale_unity = FALSE) {
   if(length(dim) == 1) {
     dim = c(dim, dim)
   }
-  mindim = min(dim)
   xy_ratio = dim[1]/dim[2]
   if(xy_ratio > 1) {
     x = seq(-width*xy_ratio,width*xy_ratio,length.out = dim[1])
@@ -31,5 +33,9 @@ generate_2d_exponential = function(falloff = 1, dim = c(11,11), width = 3) {
       testmat[i,j] = (dexp(sqrt(x[i]^2+y[j]^2),rate=1/falloff))
     }
   }
+  if(rescale_unity) {
+    temp = testmat/sum(testmat)
+    return(temp/max(temp))
+  }
   testmat/sum(testmat)
 }
